@@ -552,6 +552,17 @@ float UTopScale()
    return (float)(sqrt((double)(ctm->a * ctm->a + ctm->d * ctm->d)));
 }
 
+/*----------------------------------------------------------------------*/
+/* Return position offset relative to top-level				*/
+/*----------------------------------------------------------------------*/
+
+void UTopOffset(int *offx, int *offy)
+{
+   Matrix *ctm = DCTM;
+   *offx = (int)ctm->c;
+   *offy = (int)ctm->f;
+}
+
 /*----------------------------------------------------------------------*/
 
 float UTopTransScale(float length)
