@@ -102,18 +102,23 @@ short *collect_graphics(short *pagelist)
 /* Generate the target view of the indicated graphic image, combining	*/
 /* the image's scale and rotation and the zoom factor of the current	*/
 /* view.								*/
+/*									*/
+/* If the graphic is at the wrong scale or rotation but is not redrawn	*/
+/* because it is outside the screen viewing area, return FALSE. 	*/
+/* Otherwise, return TRUE.						*/
 /*----------------------------------------------------------------------*/
 
-void transform_graphic(graphicptr gp)
+Boolean transform_graphic(graphicptr gp)
 {
     int width, height, twidth, theight, rotation;
-    float scale;
+    float scale, tscale;
     double cosr, sinr;
-    int x, y, c, s, hw, hh, thw, thh, xorig, yorig, crot;
+    int x, y, c, s, hw, hh, thw, thh, xorig, yorig, crot, xc, yc;
     int screen = DefaultScreen(dpy);
     static GC cmgc = (GC)NULL;
 
-    scale = gp->scale * UTopTransScale(1.0);
+    tscale = UTopTransScale(1.0);
+    scale = gp->scale * tscale;
     rotation = gp->rotation + UTopRotate();
 
     if (rotation >= 360) rotation -= 360;
@@ -121,7 +126,7 @@ void transform_graphic(graphicptr gp)
 
     /* Check if the top-level rotation and scale match the	*/
     /* saved target image.  If so, then we're done.		*/
-    if ((rotation == gp->trot) && (scale == gp->tscale)) return;
+    if ((rotation == gp->trot) && (scale == gp->tscale)) return TRUE;
 
     cosr = cos(RADFAC * rotation);
     sinr = sin(RADFAC * rotation);
@@ -139,14 +144,28 @@ void transform_graphic(graphicptr gp)
     width = gp->source->width * scale;
     height = gp->source->height * scale;
 
-    if (gp->target != NULL) XDestroyImage(gp->target);
-    if (gp->clipmask != (Pixmap)NULL) XFreePixmap(dpy, gp->clipmask);
-
     twidth = (int)(fabs(width * cosr + height * sinr));
     theight = (int)(fabs(width * sinr + height * cosr));
     if (twidth & 1) twidth++;
     if (theight & 1) theight++;
 
+    /* Check whether this instance is going to be off-screen,	*/
+    /* to avoid excessive computation.				*/
+
+    UTopOffset(&xc, &yc);
+    xc += (int)((float)gp->position.x * tscale);
+    yc = areawin->height - yc;
+    yc += (int)((float)gp->position.y * tscale);
+
+    if (xc - (twidth >> 1) > areawin->width) return FALSE;
+    if (xc + (twidth >> 1) < 0) return FALSE;
+    if (yc - (theight >> 1) > areawin->height) return FALSE;
+    if (yc + (theight >> 1) < 0) return FALSE;
+
+    /* Generate the new target image */
+    if (gp->target != NULL) XDestroyImage(gp->target);
+    if (gp->clipmask != (Pixmap)NULL) XFreePixmap(dpy, gp->clipmask);
+
     gp->target = XCreateImage(dpy, DefaultVisual(dpy, screen),
 			DefaultDepth(dpy, screen), ZPixmap,
 			0, 0, twidth, theight, 8, 0);
@@ -156,7 +175,7 @@ void transform_graphic(graphicptr gp)
        XDestroyImage(gp->target);
        gp->target = (XImage *)NULL;
        gp->clipmask = (Pixmap)NULL;
-       return;
+       return FALSE;
     }
 
     if (rotation != 0) {
@@ -193,6 +212,7 @@ void transform_graphic(graphicptr gp)
     }
     gp->tscale = scale;
     gp->trot = rotation;
+    return TRUE;
 }
 
 /*----------------------------------------------------------------------*/
@@ -205,7 +225,7 @@ void UDrawGraphic(graphicptr gp)
     XPoint ppt;
 
     /* transform to current scale and rotation, if necessary */
-    transform_graphic(gp);
+    if (transform_graphic(gp) == FALSE) return;  /* Graphic off-screen */
 
     /* transform to current position */
     UTransformbyCTM(DCTM, &(gp->position), &ppt, 1);
@@ -252,7 +272,7 @@ Imagedata *addnewimage(char *name, int width, int height)
       iptr->filename = strdup(name);
    else
       iptr->filename = NULL;	/* must be filled in later! */
-   iptr->refcount = 1;
+   iptr->refcount = 0;		/* no calls yet */
    iptr->image = XCreateImage(dpy, DefaultVisual(dpy, screen),
 		DefaultDepth(dpy, screen), ZPixmap, 0, NULL,
 		width, height, 8, 0);
@@ -293,7 +313,6 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
     for (i = 0; i < xobjs.images; i++) {
        iptr = xobjs.imagelist + i;
        if (!strcmp(iptr->filename, filename)) {
-	  iptr->refcount++;
 	  break;
        }
     }
@@ -372,6 +391,7 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
           }
     }
 
+    iptr->refcount++;
     NEW_GRAPHIC(gp, destobject);
     destobject->parts++;
 
