@@ -539,8 +539,8 @@ proc parse_page {cellname portlist pagedata} {
 
    # Go to the next empty page
    set cpage 1
-   page $cpage
-   while {[object parts] != {}} {incr cpage ; page $cpage}
+   page $cpage -force
+   while {[object parts] != {}} {incr cpage ; page $cpage -force}
    page label $cellname
 
    foreach phrase $pagedata {
