@@ -1434,41 +1434,11 @@ void copycat()
 	 switch(ELEMENTTYPE(*(oldobj->plist + i))) {
 	    case(PATH): {
 	       register pathptr *npath, cpath = TOPATH(oldobj->plist + i);
-	       register genericptr *gpart;
+
 	       NEW_PATH(npath, (*newobj));
-	       (*npath)->style = cpath->style;
-	       (*npath)->width = cpath->width;
-	       (*npath)->parts = 0;
-	       (*npath)->plist = (genericptr *)malloc(cpath->parts *
-			sizeof(genericptr));
-               (*npath)->passed = NULL;
-	       for (gpart = cpath->plist; gpart < cpath->plist + cpath->parts;
-			gpart++) {
-		  switch(ELEMENTTYPE(*gpart)){
-		     case ARC: {
-			arcptr copyarc = TOARC(gpart);
-			arcptr *newarc;
-			NEW_ARC(newarc, (*npath));
-			arccopy(*newarc, copyarc);
-			(*npath)->parts++;
-			} break;
-		     case POLYGON: {
-                        polyptr copypoly = TOPOLY(gpart);
-                        polyptr *newpoly;
-                        NEW_POLY(newpoly, (*npath));
-                        polycopy(*newpoly, copypoly);
-                        (*npath)->parts++;
-                        } break;
-                     case SPLINE: {
-                        splineptr copyspline = TOSPLINE(gpart);
-                        splineptr *newspline;
-                        NEW_SPLINE(newspline, (*npath));
-                        splinecopy(*newspline, copyspline);
-                        (*npath)->parts++;
-                        } break;
-		  }
-	       }	
+	       pathcopy(*npath, cpath);
 	       } break;
+
 	    case(ARC): {
 	       register arcptr *narc, carc = TOARC(oldobj->plist + i);
 
@@ -1477,33 +1447,29 @@ void copycat()
                } break;
       
 	    case(POLYGON): {
-	       register polyptr *npoly, cpoly;
+	       register polyptr *npoly, cpoly = TOPOLY(oldobj->plist + i);
 
-	       cpoly = TOPOLY(oldobj->plist + i);
 	       NEW_POLY(npoly, (*newobj));
 	       polycopy(*npoly, cpoly);
                } break;
 
 	    case(SPLINE): {
-	       register splineptr *nspl, cspl;
+	       register splineptr *nspl, cspl = TOSPLINE(oldobj->plist + i);
 
-	       cspl = TOSPLINE(oldobj->plist + i);
 	       NEW_SPLINE(nspl, (*newobj));
 	       splinecopy(*nspl, cspl);
       	       } break;
 
 	    case(LABEL): {
-	       register labelptr *nlabel, clabel;
+	       register labelptr *nlabel, clabel = TOLABEL(oldobj->plist + i);
 
-	       clabel = TOLABEL(oldobj->plist + i);
 	       NEW_LABEL(nlabel, (*newobj));
 	       labelcopy(*nlabel, clabel);
                } break;
       
 	    case(OBJINST): {
-	       register objinstptr *ninst, cinst;
+	       register objinstptr *ninst, cinst = TOOBJINST(oldobj->plist + i);
 
-	       cinst = TOOBJINST(oldobj->plist + i);
 	       NEW_OBJINST(ninst, (*newobj));
 	       instcopy(*ninst, cinst);
                } break;
@@ -1757,7 +1723,6 @@ void startcatalog(xcWidget w, pointertype libmod, caddr_t nulldata)
    /* to a library from the library directory or vice versa, or	    */
    /* library to library.					    */
 
-
    if (!(((is_library(topobject) >= 0)
 		|| (areawin->topinstance == xobjs.libtop[LIBLIB])
 		|| (areawin->topinstance == xobjs.libtop[PAGELIB]))
