@@ -285,9 +285,13 @@ void free_element_param(genericptr thiselem, eparamptr thisepp)
 /*----------------------------------------------------------------------*/
 /* Free an instance parameter.  Note that this routine does not free	*/
 /* any strings associated with string parameters!			*/
+/*									*/
+/* Return a pointer to the entry before the one deleted, so we can use	*/
+/* free_instance_param() inside a loop over an instance's parameters	*/
+/* without having to keep track of the previous pointer position.	*/
 /*----------------------------------------------------------------------*/
 
-void free_instance_param(objinstptr thisinst, oparamptr thisparam)
+oparamptr free_instance_param(objinstptr thisinst, oparamptr thisparam)
 {
    oparamptr ops, lastops = NULL;
 
@@ -303,6 +307,7 @@ void free_instance_param(objinstptr thisinst, oparamptr thisparam)
       }
       lastops = ops; 
    }
+   return lastops;
 }
 
 /*----------------------------------------------------------------------*/
@@ -499,7 +504,7 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 		  free(promoted);
 		  break;
 	       case XC_EXPR:
-		  if ((promoted = evaluate_expr(dps, pinst)) == NULL) continue;
+		  if ((promoted = evaluate_expr(thisobj, dps, pinst)) == NULL) continue;
 		  if (sscanf(promoted, "%g", &fval) == 1)
 		     ival = (int)(fval + 0.5);
 		  free(promoted);
