@@ -34,13 +34,13 @@ extern void xctk_dragfilebox(ClientData, XEvent *);
 extern void tcl_stdflush(FILE *);
 extern void tcl_printf(FILE *, const char *, ...);
 extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
-extern Tcl_Obj *evaluate_raw(oparamptr, int *);
+extern Tcl_Obj *evaluate_raw(objectptr, oparamptr, objinstptr, int *);
 extern char *TCL_to_PS(char *);
 extern XCWindowData *GUI_init(int, Tcl_Obj *CONST objv[]);
 extern void build_app_database(Tk_Window);
 #endif
 
-extern char *evaluate_expr(oparamptr, objinstptr);
+extern char *evaluate_expr(objectptr, oparamptr, objinstptr);
 
 /* from opengl.c:  compatibility functions for OpenGL/X11 */
 
@@ -362,6 +362,8 @@ extern short checkbounds(void);
 extern void window_to_user(short, short, XPoint *);
 extern void user_to_window(XPoint, XPoint *);
 extern float UTopScale(void);
+extern int UTopRotation(void);
+extern void UTopOpffset(int *, int *);
 extern float UTopTransScale(float);
 extern XPoint UGetCursor(void);
 extern XPoint UGetCursorPos(void);
@@ -716,7 +718,7 @@ extern oparamptr find_param(objinstptr, char *);
 extern int get_num_params(objectptr);
 extern void free_all_eparams(genericptr);
 extern void free_object_param(objectptr, oparamptr);
-extern void free_instance_param(objinstptr, oparamptr);
+extern oparamptr free_instance_param(objinstptr, oparamptr);
 extern void free_element_param(genericptr, eparamptr);
 
 extern oparamptr make_new_parameter(char *);
