@@ -56,7 +56,7 @@ short del;
 /* calling routine to free it.						*/
 /*----------------------------------------------------------------------*/
 
-char *evaluate_expr(oparamptr ops, objinstptr pinst)
+char *evaluate_expr(objectptr thisobj, oparamptr ops, objinstptr pinst)
 {
    if (ops->type != XC_EXPR) return NULL;
    return strdup(ops->parameter.expr);
@@ -348,6 +348,11 @@ stringpart *mergestring(stringpart *firststr)
 /* parameters encountered.  If FALSE, then we assume that all		*/
 /* expressions have been computed previously, and may use the recorded	*/
 /* instance value.							*/
+/*									*/
+/* 11/20/06---changed to allow two different static strings to save	*/
+/* promoted results.  This is necessary because we may be comparing	*/
+/* two promoted results in, e.g., stringcomprelaxed(), and we don't	*/
+/* want to overwrite the first result with the second.			*/
 /*----------------------------------------------------------------------*/
 
 stringpart *linkstring(objinstptr localinst, stringpart *strstart,
@@ -355,7 +360,8 @@ stringpart *linkstring(objinstptr localinst, stringpart *strstart,
 {
    char *key;
    stringpart *tmpptr, *nextptr = NULL;
-   static stringpart *promote = NULL;
+   static stringpart *promote[2] = {NULL, NULL};
+   static unsigned char pidx = 0;
    oparamptr ops;
 
    if (strstart->type != PARAM_START) return NULL;
@@ -381,46 +387,48 @@ stringpart *linkstring(objinstptr localinst, stringpart *strstart,
 
    if (ops->type != XC_STRING) {
 
-      if (promote == NULL) {
+      if (promote[pidx] == NULL) {
          /* Generate static string for promoting numerical parameters */
-         tmpptr = makesegment(&promote, NULL);
+         tmpptr = makesegment(&promote[pidx], NULL);
          tmpptr->type = TEXT_STRING;
-         tmpptr = makesegment(&promote, NULL);
+         tmpptr = makesegment(&promote[pidx], NULL);
          tmpptr->type = PARAM_END;
       }
       else {
-	 if (promote->data.string != NULL) {
-	    free(promote->data.string);
-	    promote->data.string = NULL;
+	 if (promote[pidx]->data.string != NULL) {
+	    free(promote[pidx]->data.string);
+	    promote[pidx]->data.string = NULL;
 	 }
       }
 
       /* Promote numerical type to string */
       if (ops->type == XC_INT) {
-	 promote->data.string = (char *)malloc(13);
-	 sprintf(promote->data.string, "%12d", ops->parameter.ivalue);
-         nextptr = promote;
+	 promote[pidx]->data.string = (char *)malloc(13);
+	 sprintf(promote[pidx]->data.string, "%12d", ops->parameter.ivalue);
+         nextptr = promote[pidx++];
       }
       else if (ops->type == XC_FLOAT) {
-	 promote->data.string = (char *)malloc(13);
-	 sprintf(promote->data.string, "%g", (double)(ops->parameter.fvalue));
-         nextptr = promote;
+	 promote[pidx]->data.string = (char *)malloc(13);
+	 sprintf(promote[pidx]->data.string, "%g", (double)(ops->parameter.fvalue));
+         nextptr = promote[pidx++];
       }
       else {	/* ops->type == XC_EXPR */
 	 oparamptr ips;
 	 if (!compute_exprs && (ips = match_instance_param(localinst, key))
 		!= NULL && (ips->type == XC_STRING)) {
 	    nextptr = ips->parameter.string;
-	    promote->data.string = NULL;
+	    promote[pidx]->data.string = NULL;
 	 }
 	 else {
-	    promote->data.string = evaluate_expr(ops, localinst);
-	    if (promote->data.string != NULL)
-               nextptr = promote;
+	    promote[pidx]->data.string = evaluate_expr(((localinst == NULL) ?
+			topobject : localinst->thisobject), ops, localinst);
+	    if (promote[pidx]->data.string != NULL)
+               nextptr = promote[pidx++];
 	    else
 	       nextptr = NULL;
 	 }
       }
+      pidx &= 0x1;	/* pidx toggles between 0 and 1 */
    }
    else
       nextptr = ops->parameter.string;
